BufferArray

Struct BufferArray 

pub struct BufferArray<N>
where N: ArrayLength,
{ /* private fields */ }
An owned audio buffer stored inline as an array with an arbitrary number of channels containing 64 (MAX_BUFFER_SIZE) samples per channel. Samples are stored non-interleaved. The number of channels must be known at compile time: the size N is given as a type-level integer (U0, U1, …).

Implementations

Source

impl<N> BufferArray<N>
where N: ArrayLength,

pub fn new() -> BufferArray<N>

Create new buffer and initialize it with zeros.

pub fn at(&self, channel: usize, i: usize) -> f32x8

Access value at index i (0 <= i <= 7) of channel.

pub fn at_f32(&self, channel: usize, i: usize) -> f32

Get f32 value at index i (0 <= i <= 63) of channel.

pub fn set(&mut self, channel: usize, i: usize, value: f32x8)

Set value at index i (0 <= i <= 7) of channel.

pub fn set_f32(&mut self, channel: usize, i: usize, value: f32)

Get f32 value at index i (0 <= i <= 63) of channel.

pub fn channels(&self) -> usize

Number of channels in this buffer.

pub fn length(&self) -> usize

Length of the buffer is 8 SIMD samples.

pub fn len(&self) -> usize

Length of the buffer is 8 SIMD samples.

pub fn clear(&mut self)

Fill all channels of buffer with zeros.

pub fn channel(&self, channel: usize) -> &[f32x8]

Get channel slice.

pub fn channel_mut(&mut self, channel: usize) -> &mut [f32x8]

Get mutable channel slice.

pub fn channel_f32(&mut self, channel: usize) -> &[f32]

Get channel as a scalar slice.

pub fn channel_f32_mut(&mut self, channel: usize) -> &mut [f32]

Get channel as a mutable scalar slice.

pub fn buffer_ref(&self) -> BufferRef<'_>

Get immutably borrowed buffer.

pub fn buffer_mut(&mut self) -> BufferMut<'_>

Get mutably borrowed buffer.