pub struct BufferArray<N>where
N: ArrayLength,{ /* private fields */ }Expand description
An owned audio buffer stored inline as an array with an arbitrary number of channels
containing 64 (MAX_BUFFER_SIZE) samples per channel.
Samples are stored non-interleaved.
The number of channels must be known at compile time:
the size N is given as a type-level integer (U0, U1, …).
Implementations
Sourceimpl<N> BufferArray<N>where
N: ArrayLength,
impl<N> BufferArray<N>where
N: ArrayLength,
Sourcepub fn new() -> BufferArray<N>
pub fn new() -> BufferArray<N>
Create new buffer and initialize it with zeros.
Sourcepub fn at(&self, channel: usize, i: usize) -> f32x8
pub fn at(&self, channel: usize, i: usize) -> f32x8
Access value at index i (0 <= i <= 7) of channel.
Sourcepub fn at_f32(&self, channel: usize, i: usize) -> f32
pub fn at_f32(&self, channel: usize, i: usize) -> f32
Get f32 value at index i (0 <= i <= 63) of channel.
Sourcepub fn set(&mut self, channel: usize, i: usize, value: f32x8)
pub fn set(&mut self, channel: usize, i: usize, value: f32x8)
Set value at index i (0 <= i <= 7) of channel.
Sourcepub fn set_f32(&mut self, channel: usize, i: usize, value: f32)
pub fn set_f32(&mut self, channel: usize, i: usize, value: f32)
Get f32 value at index i (0 <= i <= 63) of channel.
Sourcepub fn channel_mut(&mut self, channel: usize) -> &mut [f32x8]
pub fn channel_mut(&mut self, channel: usize) -> &mut [f32x8]
Get mutable channel slice.
Sourcepub fn channel_f32(&mut self, channel: usize) -> &[f32]
pub fn channel_f32(&mut self, channel: usize) -> &[f32]
Get channel as a scalar slice.
Sourcepub fn channel_f32_mut(&mut self, channel: usize) -> &mut [f32]
pub fn channel_f32_mut(&mut self, channel: usize) -> &mut [f32]
Get channel as a mutable scalar slice.
Sourcepub fn buffer_ref(&self) -> BufferRef<'_>
pub fn buffer_ref(&self) -> BufferRef<'_>
Get immutably borrowed buffer.
Sourcepub fn buffer_mut(&mut self) -> BufferMut<'_>
pub fn buffer_mut(&mut self) -> BufferMut<'_>
Get mutably borrowed buffer.